@@ -10,7 +10,9 @@
 #' @return A data frame of class 'data.frame', "sf" and 'ARPALdf'.
 #'
 #' @examples
-#' # shape <- get_Lombardia_geospatial(NUTS_level = "LAU")
+#' \donttest{
+#' shape <- get_Lombardia_geospatial(NUTS_level = "LAU")
+#' }
 #'
 #' @export
 
@@ -23,6 +25,14 @@ get_Lombardia_geospatial <- function(NUTS_level = "LAU") {
     stop("Selected NUTS not available: use one of 'NUTS2', 'NUTS3' and 'LAU'",call. = FALSE)
   }
 
+  ##### Check online availability for zoning metadata from GitHub
+  temp <- tempfile()
+  res <- curl::curl_fetch_disk("https://github.com/PaoloMaranzano/ARPALData/raw/main/Shape_Comuni_Lombardia.zip", temp)
+  if(res$status_code != 200) {
+    stop(paste0("The internet resource for shapefile of Lombardy's municipalities (from GitHub) is not available at the moment, try later.
+                  If the problem persists, please contact the package maintainer."))
+  }
+
   # Dowload shape file for Lombardy municipalities
   temp1 <- tempfile()
   temp2 <- tempfile()
